<p align="center" id='大礼包-banner'>
    <a target="_blank" href='http://python4office.cn/fuli/fuli-source-0726/'>
    <img src="https://banner-1300615378.cos.ap-guangzhou.myqcloud.com/%E6%A8%AA%E6%9D%A1/Python%E5%A4%A7%E7%A4%BC%E5%8C%85.jpg" width="100%"/>
    </a>   
</p>



<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
    <a target="_blank" href='https://github.com/CoderWanFeng/poemail'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/poemail.svg?style=social" alt="github star"/>
    </a>
    	<a target="_blank" href='https://gitee.com/CoderWanFeng/poemail'>
		<img src='https://gitee.com/CoderWanFeng/poemail/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/NN2pX2bQPpczOeGF4ARNtw">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>
</p>


-------------------------------------------------------------------------------

## 📚简介

``poemail``是用Python自动发邮件的工具箱

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ poemail -U
```

-------------------------------------------------------------------------------

## 📝功能

[📘官方教程：https://www.python-office.com/course-002/poemail/poemail.html](https://www.python-office.com/course-002/poemail/poemail.html)


- 第1讲：[Python环境的下载和安装](https://www.python-office.com/course-002/poemail/docs/1-install_python_pycharm.html)
- 第2讲：[免费开通权限](https://www.python-office.com/course-002/poemail/docs/2-auth_mail.html)
- 第3讲：[1行代码，自动发正文](https://www.python-office.com/course-002/poemail/docs/3-send_mail_content.html)
- 第4讲：[1行代码，自动发正文+附件](https://www.python-office.com/course-002/poemail/docs/4-send_mail_content_file.html)
- 第5讲：[自动批量发送](https://www.python-office.com/course-002/poemail/docs/5-batch_send_mail_content_file.html)
- 第6讲：[1行代码，自动下载邮件的附件](https://www.python-office.com/course-002/poemail/docs/6-receive_mail_attchment.html)
- 第7讲：[配置其它邮箱](https://www.python-office.com/course-002/poemail/docs/7-other_email.html)

## 🏗️添砖加瓦

``poemail``欢迎任何人来添砖加瓦，贡献代码，建议提交的pr（pull request）符合一些规范，规范如下：

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和代码本身有关的问题，不建议进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/poemail/issues)

-------------------------------------------------------------------------------

## 📌用户群

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>